spin_texture — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# spin_texture

FermiSurface.spin_texture(sx, sy, sz, spin=None, interpolation=300)

  This method plots spin texture of the 2d fermi surface

  Only 2D layer geometry along z. It is like a enhanced version of ‘plot’ method.

  sx, sy, sz are spin projected Nkpoints x Nbands numpy arrays. They also are (already) projected by orbital and atom (from other class)

  Parameters:

    - sx (np.ndarray) – Spin projected array for the x component. size (n_kpoints,n_bands)

    - sy (np.ndarray) – Spin projected array for the y component. size (n_kpoints,n_bands)

    - sz (np.ndarray) – Spin projected array for the z component. size (n_kpoints,n_bands)

    - spin (List or array-like, optional) – List of marker colors for the arrows, by default None

    - interpolation (int, optional) – The interpolation level, by default 300

  Raises:

    RuntimeError – Raise error if find energy was not called before plotting.